==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/da.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
    "Storage invalid" : "Lagerplads er ugyldig",
    "Unknown error" : "Ukendt fejl",
    "All files" : "Alle filer",
    "Recent" : "Seneste",
    "Favorites" : "Foretrukne",
    "File could not be found" : "Filen kunne ikke findes",
    "Move or copy" : "Flyt eller kopier",
    "Download" : "Hent",
    "Delete" : "Slet",
    "Home" : "Hjem",
    "Close" : "Luk",
    "Could not create folder \"{dir}\"" : "Kunne ikke oprette mappen \"{dir}\"",
    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
    "Upload cancelled." : "Upload afbrudt.",
    "Processing files …" : "Behandler filer...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
    "Target folder \"{dir}\" does not exist any more" : "Destinationsmappen \"{dir}\" findes ikke længere",
    "Not enough free space" : "Ikke nok fri plads",
    "An unknown error has occurred" : "En ukendt fejl er opstået",
    "Uploading …" : "Uploader ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Destinationsmappen findes ikke længere",
    "Error when assembling chunks, status code {status}" : "Fejl ved montering af klumper, statuskode {status}",
    "Actions" : "Handlinger",
    "Rename" : "Omdøb",
    "Copy" : "Kopier",
    "Choose target folder" : "Vælg destinationsmappe",
    "Open" : "Åbn",
    "Delete file" : "Slet fil",
    "Delete folder" : "Slet mappe",
    "Disconnect storage" : "Frakobl lager",
    "Unshare" : "Ophæv deling",
    "Could not load info for file \"{file}\"" : "Kunne ikke indlæse information for filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Vælg",
    "Pending" : "Afventer",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Denne operation er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - der findes allerede en fil med dette navn",
    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
    "copy" : "kopiér",
    "Could not copy \"{file}\", target exists" : "Kunne ikke kopiere \"{file}\" - der findes allerede en fil med dette navn",
    "Could not copy \"{file}\"" : "Kunne ikke kopiere \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopirede {origin} ind i {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "kopierede {origin} og {nbfiles} andre filer ind i {destination}",
    "{newName} already exists" : "{newName} eksistere allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunne ikke omdøbe \"{fileName}\", den findes ikke længere",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" bruges allerede i mappen \"{dir}\". Vælg et andet navn.",
    "Could not rename \"{fileName}\"" : "Kunne ikke omdøbe \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunne ikke oprette filen \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunne ikke oprette filen \"{file}\", da den allerede findes",
    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke oprette mappen \"{dir}\", da den allerede findes",
    "Error deleting file \"{fileName}\"." : "Fejl under sletning af filen \"{fileName}\"",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søgeresultater i andre mapper efter {tag}{filter}{endtag}",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n skujlte inkluderet","%n skujlte inkluderet"],
    "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
    "New" : "Ny",
    "{used} of {quota} used" : "{used} af {quota} brugt",
    "{used} used" : "{used} brugt",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" er ikke tilladt i et filnavn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tilladt filtype",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opbevaringspladsen tilhørende {owner} er fyldt op - filer kan ikke længere opdateres eller synkroniseres!",
    "Your storage is full, files can not be updated or synced anymore!" : "Din opbevaringsplads er fyldt op, filer kan ikke opdateres eller synkroniseres længere!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opbevaringspladsen tilhørende {owner} er næsten fyldt op ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Din opbevaringsplads er næsten fyldt op ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["match '{filter}'","match '{filter}'"],
    "View in folder" : "Vis i mappe",
    "Copied!" : "Kopieret",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte link (virker kun for brugere der har adgang til denne fil/mappe)",
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gjort til foretrukken",
    "Favorite" : "Foretrukken",
    "New folder" : "Ny Mappe",
    "Upload file" : "Upload fil",
    "Not favorited" : "Ingen foretrukne",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Tilføj til favoritter",
    "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
    "Added to favorites" : "Tilføjet til favoritter",
    "Removed from favorites" : "Fjernet fra favoritter",
    "You added {file} to your favorites" : "Du har tilføjet {file} til dine favoritter",
    "You removed {file} from your favorites" : "Du har fjernet {file} fra dine favoritter",
    "File changes" : "Fil ændringer",
    "Created by {user}" : "Oprettet af {user}",
    "Changed by {user}" : "Ændret af {user}",
    "Deleted by {user}" : "Slettet af {user}",
    "Restored by {user}" : "Gendannet af {user}",
    "Renamed by {user}" : "Omdøbt af {user}",
    "Moved by {user}" : "Flyttet af {user}",
    "\"remote user\"" : "\"ekstern bruger\"",
    "You created {file}" : "Du har oprettet {file}",
    "You created an encrypted file in {file}" : "Du har oprettet en krypteret fil i {file}",
    "{user} created {file}" : "{user} oprettede {file}",
    "{user} created an encrypted file in {file}" : "{user} har oprettet en krypteret fil i {file}",
    "{file} was created in a public folder" : "{file} blev oprettet i en offentlig mappe",
    "You changed {file}" : "Du ændrede {file}",
    "You changed an encrypted file in {file}" : "Du har ændret en krypteret fil i {file}",
    "{user} changed {file}" : "{user} ændrede {file}",
    "{user} changed an encrypted file in {file}" : "{user} har ændret en krypteret fil i {file}",
    "You deleted {file}" : "Du slettede {file}",
    "You deleted an encrypted file in {file}" : "Du har slettet en krypteret fil i {file}",
    "{user} deleted {file}" : "{user} slettede {file}",
    "{user} deleted an encrypted file in {file}" : "{user} har slettet en krypteret fil i {file}",
    "You restored {file}" : "Du gendannede {file}",
    "{user} restored {file}" : "{user} gendannede {file}",
    "You renamed {oldfile} to {newfile}" : "Du omdøbte {oldfile} til {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} omdøbte {oldfile} til {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttede {oldfile} til {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttede {oldfile} til {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil er blevet tilføjet eller fjernet fra dine <strong>favoritter</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong> eller <strong>omdøbt</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapper er blevet <strong>oprettet</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe er blevet <strong>slettet</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begræns noter om oprettelse og ændringer af dine <strong>favorit filer</strong> <em>(Kun streaming)</em>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe er blevet <strong>gendannet</strong>",
    "Unlimited" : "Ubegrænset",
    "Upload (max. %s)" : "Upload (max. %s)",
    "%s used" : "%s brugt",
    "Settings" : "Indstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Brug denne adresse til at <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">få adgang til dine filer via WebDAV</a>",
    "No files in here" : "Her er ingen filer",
    "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Select all" : "Vælg alle",
    "Upload too large" : "Upload er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
    "No favorites yet" : "Ingen foretrukne endnu",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
    "Tags" : "Mærker",
    "Deleted files" : "Slettede filer",
    "Shared with others" : "Delt med andre",
    "Shared with you" : "Delt med dig",
    "Shared by link" : "Delt via link",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekst file.txt",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Maksimal upload-størrelse",
    "max. possible: " : "max. mulige: ",
    "Save" : "Gem",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det tage 5 minuter for ændringerne at blive udført.",
    "Missing permissions to edit from here." : "Rettighed mangler til at redigere på dette sted",
    "Cancel upload" : "Annuller upload ",
    "%s of %s used" : "%s af %s brugt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/da.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
    "Storage invalid" : "Lagerplads er ugyldig",
    "Unknown error" : "Ukendt fejl",
    "All files" : "Alle filer",
    "Recent" : "Seneste",
    "Favorites" : "Foretrukne",
    "File could not be found" : "Filen kunne ikke findes",
    "Move or copy" : "Flyt eller kopier",
    "Download" : "Hent",
    "Delete" : "Slet",
    "Home" : "Hjem",
    "Close" : "Luk",
    "Could not create folder \"{dir}\"" : "Kunne ikke oprette mappen \"{dir}\"",
    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
    "Upload cancelled." : "Upload afbrudt.",
    "Processing files …" : "Behandler filer...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
    "Target folder \"{dir}\" does not exist any more" : "Destinationsmappen \"{dir}\" findes ikke længere",
    "Not enough free space" : "Ikke nok fri plads",
    "An unknown error has occurred" : "En ukendt fejl er opstået",
    "Uploading …" : "Uploader ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Destinationsmappen findes ikke længere",
    "Error when assembling chunks, status code {status}" : "Fejl ved montering af klumper, statuskode {status}",
    "Actions" : "Handlinger",
    "Rename" : "Omdøb",
    "Copy" : "Kopier",
    "Choose target folder" : "Vælg destinationsmappe",
    "Open" : "Åbn",
    "Delete file" : "Slet fil",
    "Delete folder" : "Slet mappe",
    "Disconnect storage" : "Frakobl lager",
    "Unshare" : "Ophæv deling",
    "Could not load info for file \"{file}\"" : "Kunne ikke indlæse information for filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Vælg",
    "Pending" : "Afventer",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Denne operation er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - der findes allerede en fil med dette navn",
    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
    "copy" : "kopiér",
    "Could not copy \"{file}\", target exists" : "Kunne ikke kopiere \"{file}\" - der findes allerede en fil med dette navn",
    "Could not copy \"{file}\"" : "Kunne ikke kopiere \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopirede {origin} ind i {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "kopierede {origin} og {nbfiles} andre filer ind i {destination}",
    "{newName} already exists" : "{newName} eksistere allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunne ikke omdøbe \"{fileName}\", den findes ikke længere",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" bruges allerede i mappen \"{dir}\". Vælg et andet navn.",
    "Could not rename \"{fileName}\"" : "Kunne ikke omdøbe \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunne ikke oprette filen \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunne ikke oprette filen \"{file}\", da den allerede findes",
    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke oprette mappen \"{dir}\", da den allerede findes",
    "Error deleting file \"{fileName}\"." : "Fejl under sletning af filen \"{fileName}\"",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søgeresultater i andre mapper efter {tag}{filter}{endtag}",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n skujlte inkluderet","%n skujlte inkluderet"],
    "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
    "New" : "Ny",
    "{used} of {quota} used" : "{used} af {quota} brugt",
    "{used} used" : "{used} brugt",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" er ikke tilladt i et filnavn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tilladt filtype",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opbevaringspladsen tilhørende {owner} er fyldt op - filer kan ikke længere opdateres eller synkroniseres!",
    "Your storage is full, files can not be updated or synced anymore!" : "Din opbevaringsplads er fyldt op, filer kan ikke opdateres eller synkroniseres længere!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opbevaringspladsen tilhørende {owner} er næsten fyldt op ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Din opbevaringsplads er næsten fyldt op ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["match '{filter}'","match '{filter}'"],
    "View in folder" : "Vis i mappe",
    "Copied!" : "Kopieret",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte link (virker kun for brugere der har adgang til denne fil/mappe)",
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gjort til foretrukken",
    "Favorite" : "Foretrukken",
    "New folder" : "Ny Mappe",
    "Upload file" : "Upload fil",
    "Not favorited" : "Ingen foretrukne",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Tilføj til favoritter",
    "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
    "Added to favorites" : "Tilføjet til favoritter",
    "Removed from favorites" : "Fjernet fra favoritter",
    "You added {file} to your favorites" : "Du har tilføjet {file} til dine favoritter",
    "You removed {file} from your favorites" : "Du har fjernet {file} fra dine favoritter",
    "File changes" : "Fil ændringer",
    "Created by {user}" : "Oprettet af {user}",
    "Changed by {user}" : "Ændret af {user}",
    "Deleted by {user}" : "Slettet af {user}",
    "Restored by {user}" : "Gendannet af {user}",
    "Renamed by {user}" : "Omdøbt af {user}",
    "Moved by {user}" : "Flyttet af {user}",
    "\"remote user\"" : "\"ekstern bruger\"",
    "You created {file}" : "Du har oprettet {file}",
    "You created an encrypted file in {file}" : "Du har oprettet en krypteret fil i {file}",
    "{user} created {file}" : "{user} oprettede {file}",
    "{user} created an encrypted file in {file}" : "{user} har oprettet en krypteret fil i {file}",
    "{file} was created in a public folder" : "{file} blev oprettet i en offentlig mappe",
    "You changed {file}" : "Du ændrede {file}",
    "You changed an encrypted file in {file}" : "Du har ændret en krypteret fil i {file}",
    "{user} changed {file}" : "{user} ændrede {file}",
    "{user} changed an encrypted file in {file}" : "{user} har ændret en krypteret fil i {file}",
    "You deleted {file}" : "Du slettede {file}",
    "You deleted an encrypted file in {file}" : "Du har slettet en krypteret fil i {file}",
    "{user} deleted {file}" : "{user} slettede {file}",
    "{user} deleted an encrypted file in {file}" : "{user} har slettet en krypteret fil i {file}",
    "You restored {file}" : "Du gendannede {file}",
    "{user} restored {file}" : "{user} gendannede {file}",
    "You renamed {oldfile} to {newfile}" : "Du omdøbte {oldfile} til {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} omdøbte {oldfile} til {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttede {oldfile} til {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttede {oldfile} til {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil er blevet tilføjet eller fjernet fra dine <strong>favoritter</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong> eller <strong>omdøbt</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapper er blevet <strong>oprettet</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe er blevet <strong>slettet</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begræns noter om oprettelse og ændringer af dine <strong>favorit filer</strong> <em>(Kun streaming)</em>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe er blevet <strong>gendannet</strong>",
    "Unlimited" : "Ubegrænset",
    "Upload (max. %s)" : "Upload (max. %s)",
    "Accept" : "Accepter",
    "File Management" : "Filhåndtering",
    "Change" : "Ændr",
    "%s used" : "%s brugt",
    "%1$s of %2$s used" : "%1$s af %2$s brugt",
    "Settings" : "Indstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Brug denne adresse til at <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">få adgang til dine filer via WebDAV</a>",
    "No files in here" : "Her er ingen filer",
    "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Select all" : "Vælg alle",
    "Upload too large" : "Upload er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
    "No favorites yet" : "Ingen foretrukne endnu",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
    "Tags" : "Mærker",
    "Deleted files" : "Slettede filer",
    "Shares" : "Delinger",
    "Shared with others" : "Delt med andre",
    "Shared with you" : "Delt med dig",
    "Shared by link" : "Delt via link",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekst file.txt",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Maksimal upload-størrelse",
    "max. possible: " : "max. mulige: ",
    "Save" : "Gem",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det tage 5 minuter for ændringerne at blive udført.",
    "Missing permissions to edit from here." : "Rettighed mangler til at redigere på dette sted",
    "Cancel upload" : "Annuller upload ",
    "%s of %s used" : "%s af %s brugt"
},
"nplurals=2; plural=(n != 1);");
